<?php
// ------------------------------------------------------------------------- //
// <G a n e s h a> - Free Web Based Training System                          //
// ------------------------------------------------------------------------- //
// <G a n e s h a> - Plate-forme de téléformation gratuite et en open source //
// ------------------------------------------------------------------------- //
// Copyright (C) 2001-2003  Anéma Formation  <http://www.anema.fr/>          //
// ------------------------------------------------------------------------- //
//            Developer : Georges CALDEIRA <gcaldeira@anemalab.org>          //
// ------------------------------------------------------------------------- //
//               Infos on project <http://anemalab.org/>                     //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
// -------------------------------------------------------------------------
//
// Addon BNO (Bloc-notes et Objectifs) pour Ganesha
// Developper : pyg_listes@exiup.com
// -------------------
// Desc : Page principale de saisie des infos (côté tuteur)
//
// -------------------------------------------------------------------------

	include_once('./anema.inc.php');

	// Detection du type d'outil : 1=Bloc-notes ; 2=Objectifs
	if (isset($HTTP_GET_VARS['type_outil'])) {
		$type_outil = $HTTP_GET_VARS['type_outil'];
	} else {
		echo "Perte du type d'outil ($type_outil)";
		exit();
	}

	$connexion = $HTTP_GET_VARS['connexion'];

	InitPageHtmlNoCacheBNO()	;

	HeaderBNOTuteur();
	BR();
	BeginFormulaireBNO("", "bno_post.php?connexion=".$gconnexionid);

	// --------- Menu stagiaire ---------
	if ($HTTP_GET_VARS['menu']=="1") { //on est sur un menu stagiaire
		$ClsBno->TableUtilisateur();
	}
	if (isset($HTTP_GET_VARS['id_modif']) && ($HTTP_GET_VARS['id_modif']!="aucun") ) { //on a choisi un stagiaire (non nul)
		AfficheTa();
	}
	// fin menu stagiaire
	// ---------- Menu Général --------------
	if ($HTTP_GET_VARS['menu']=="2") { //on est sur un menu stagiaire
		$id_modif="0";					// vaut pour l'ensemble des stagiaire => Général
		AfficheTa();
	}
	// fin menu général

	EndFormulaireBNO();

	CloseWindow()	;
	footer()		;
	ClosePageHtml()	;

?>